Crate bt_toast

Crate bt_toast 

Re-exports

pub use Toast2_completions::Component::Toast2;

Structs

Toast2Props
Properties for the Toast2 component.
ToastMgr
The ToastMgr struct is used to manage toast notifications in a Dioxus application using Bootstrap. It has four properties: show_toast: A boolean indicating whether a toast notification should be shown. toast_message: A string containing the message to be displayed in the toast notification. toast_type: A character indicating the type of toast notification (I for info, S for success, W for waiting, C for caution/warning, E for error). wait_msg: A string containing the default waiting message.

Functions

Toast2
Props